package com.foreverwin.mesnac.meapi.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.foreverwin.mesnac.meapi.util.StringUtils;
import com.foreverwin.mesnac.meapi.model.Item;
import com.foreverwin.mesnac.meapi.service.ItemService;
import com.foreverwin.modular.core.util.CommonMethods;
import com.foreverwin.modular.core.util.FrontPage;
import com.foreverwin.modular.core.util.R;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author Ervin Chen
 * @since 2020-10-19
 */
@RestController
@RequestMapping("/ITEM")
public class ItemController {

    @Autowired
    public ItemService itemService;

    /**
     * 根据id查询
     *
     * @param id 主键
     * @return
     */
    @ResponseBody
    @GetMapping("/{id:.+}")
    public R getItemById(@PathVariable String id) {
        return R.ok(itemService.getById(id));
    }

    /**
     * 查询所有数据
     *
     * @return
     */
    @ResponseBody
    @GetMapping("")
    public R getItemList(Item item) {
        List<Item> result;
        QueryWrapper<Item> queryWrapper = new QueryWrapper<>();
        queryWrapper.setEntity(item);
        result = itemService.list(queryWrapper);
        return R.ok(result);
    }

    /**
     * 查询所有数据-张漪雯
     *
     * @return
     */
    @ResponseBody
    @GetMapping("/item-select")
    public R getItemselect(Item item) {
        List<Item> result;
        QueryWrapper<Item> queryWrapper = new QueryWrapper<>();
        queryWrapper.setEntity(item);
        result = itemService.selectList(queryWrapper);
        return R.ok(result);
    }


    /**
     * 分页查询数据
     *
     * @param frontPage 分页信息
     * @return
     */
    @ResponseBody
    @GetMapping("/page")
    public R page(FrontPage<Item> frontPage, Item item) {
        IPage result;
        QueryWrapper<Item> queryWrapper = new QueryWrapper<>();
        queryWrapper.setEntity(item);
        if (frontPage.getGlobalQuery() != null && !"".equals(frontPage.getGlobalQuery().trim())) {
            //TODO modify global query
            queryWrapper.lambda().and(wrapper -> wrapper
                    .like(Item::getHandle, frontPage.getGlobalQuery())
                    .or().like(Item::getSite, frontPage.getGlobalQuery())
                    .or().like(Item::getItem, frontPage.getGlobalQuery())
                    .or().like(Item::getStatusBo, frontPage.getGlobalQuery())
                    .or().like(Item::getItemType, frontPage.getGlobalQuery())
                    .or().like(Item::getErpGtin, frontPage.getGlobalQuery())
                    .or().like(Item::getAinModelExternalId, frontPage.getGlobalQuery())
                    .or().like(Item::getQuantityRestriction, frontPage.getGlobalQuery())
                    .or().like(Item::getRouterBo, frontPage.getGlobalQuery())
                    .or().like(Item::getBomBo, frontPage.getGlobalQuery())
                    .or().like(Item::getComponentGroupBo, frontPage.getGlobalQuery())
                    .or().like(Item::getItemGroupBo, frontPage.getGlobalQuery())
                    .or().like(Item::getAssyDataTypeBo, frontPage.getGlobalQuery())
                    .or().like(Item::getPreAssembled, frontPage.getGlobalQuery())
                    .or().like(Item::getRevision, frontPage.getGlobalQuery())
                    .or().like(Item::getCurrentRevision, frontPage.getGlobalQuery())
                    .or().like(Item::getSelectorActivityBo, frontPage.getGlobalQuery())
                    .or().like(Item::getSelectorNote, frontPage.getGlobalQuery())
                    .or().like(Item::getAssignSerialAtRelease, frontPage.getGlobalQuery())
                    .or().like(Item::getDrawingName, frontPage.getGlobalQuery())
                    .or().like(Item::getUseCompFromDrawing, frontPage.getGlobalQuery())
                    .or().like(Item::getPanel, frontPage.getGlobalQuery())
                    .or().like(Item::getRemovalAssyDataTypeBo, frontPage.getGlobalQuery())
                    .or().like(Item::getInvAssyDataTypeBo, frontPage.getGlobalQuery())
                    .or().like(Item::getOriginalStatusBo, frontPage.getGlobalQuery())
                    .or().like(Item::getCreateTrackableSfc, frontPage.getGlobalQuery())
                    .or().like(Item::getMaskGroupBo, frontPage.getGlobalQuery())
                    .or().like(Item::getTransferItemGroupBo, frontPage.getGlobalQuery())
                    .or().like(Item::getUnitOfMeasure, frontPage.getGlobalQuery())
                    .or().like(Item::getCollectParentSerial, frontPage.getGlobalQuery())
                    .or().like(Item::getReqSerialChange, frontPage.getGlobalQuery())
                    .or().like(Item::getIsCollector, frontPage.getGlobalQuery())
                    .or().like(Item::getIncBatchNumber, frontPage.getGlobalQuery())
                    .or().like(Item::getTimeSensitive, frontPage.getGlobalQuery())
                    .or().like(Item::getMaxShelfLifeUnits, frontPage.getGlobalQuery())
                    .or().like(Item::getMaxFloorLifeUnits, frontPage.getGlobalQuery())
                    .or().like(Item::getNotes, frontPage.getGlobalQuery())
                    .or().like(Item::getTbCompType, frontPage.getGlobalQuery())
                    .or().like(Item::getErpBackflushing, frontPage.getGlobalQuery())
                    .or().like(Item::getStorageLocationBo, frontPage.getGlobalQuery())
                    .or().like(Item::getErpPutawayStorloc, frontPage.getGlobalQuery())
                    .or().like(Item::getProductionSupplyArea, frontPage.getGlobalQuery())
                    .or().like(Item::getUseOrderIdRel1, frontPage.getGlobalQuery())
                    .or().like(Item::getMaterialType, frontPage.getGlobalQuery())
                    .or().like(Item::getProcurementType, frontPage.getGlobalQuery())
                    .or().like(Item::getOrigin, frontPage.getGlobalQuery())
            );
        }
        result = itemService.page(frontPage.getPagePlus(), queryWrapper);
        return R.ok(result);
    }

    /**
     * 新增
     *
     * @param item 传递的实体
     * @return null 失败  实体成功
     */
    @PostMapping
    public R save(@RequestBody Item item) {
        return R.ok(itemService.save(item));
    }

    /**
     * 修改
     *
     * @param item 传递的实体
     * @return null 失败  实体成功
     */
    @PutMapping
    public R updateById(@RequestBody Item item) {
        return R.ok(itemService.updateById(item));
    }

    /**
     * 根据id删除对象
     *
     * @param id 实体ID
     * @return 0 失败  1 成功
     */
    @ResponseBody
    @RequestMapping(method = RequestMethod.DELETE, value = "/{id:.+}")
    public R removeById(@PathVariable("id") String id) {
        return R.ok(itemService.removeById(id));
    }

    /**
     * 批量删除对象
     *
     * @param ids 实体集合ID
     * @return 0 失败  1 成功
     */
    @ResponseBody
    @RequestMapping(method = RequestMethod.POST, value = "/delete-batch")
    public R removeByIds(List<String> ids) {
        return R.ok(itemService.removeByIds(ids));
    }

    /**
     * 新增
     *
     * @param item 传递的实体
     * @return null 失败  实体成功
     */
    @GetMapping("/selectItemByDesc")
    public R selectItemByDesc(Item item) {
        try {
            return R.ok(itemService.selectItemWithDesc(item));
        } catch (Exception e) {
            return R.failed(e.getMessage());
        }
    }


    @GetMapping("/getItemDetailList")
    public R getItemDetailList() {
        return R.ok(itemService.getItemDetailList());

    }

    @GetMapping("/getBklasItem")
    public R getBklasItem(FrontPage<Item> frontPage) {
        return R.ok(itemService.getBklasItem(frontPage.getPagePlus(), frontPage.getGlobalQuery()));

    }



    @ResponseBody
    @GetMapping("/getRawMaterial")
    public R getRawMaterial(FrontPage frontPage) {
        String global = frontPage.getGlobalQuery();
        return R.ok(itemService.getRawMaterial(frontPage.getPagePlus(), global));

    }

}