package com.foreverwin.mesnac.meapi.controller;

import com.foreverwin.modular.core.util.R;
import com.foreverwin.modular.core.util.FrontPage;
import com.foreverwin.modular.core.util.CommonMethods;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import com.foreverwin.mesnac.meapi.service.ResrceService;
import com.foreverwin.mesnac.meapi.model.Resrce;
import java.util.List;

/**
 *
 * @author Leon.L
 * @since 2021-05-26
 */
@RestController
@RequestMapping("/RESRCE")
public class ResrceController {

    @Autowired
    public ResrceService resrceService;

    /**
    * 根据id查询
    *
    * @param id 主键
    * @return
    */
    @ResponseBody
    @GetMapping("/{id:.+}")
    public R getResrceById(@PathVariable String id) {
        return R.ok( resrceService.getById(id));
    }

    /**
     * 查询所有数据
     *
     * @return
     */
    @ResponseBody
    @GetMapping("")
    public R getResrceList(Resrce resrce){
        List<Resrce> result;
        QueryWrapper<Resrce> queryWrapper = new QueryWrapper<>();
        queryWrapper.setEntity(resrce);
        result = resrceService.list(queryWrapper);
        return R.ok(result);
    }

    /**
     * 分页查询数据
     *
     * @param frontPage  分页信息
     * @return
     */
    @ResponseBody
    @GetMapping("/page")
    public R page(FrontPage<Resrce> frontPage, Resrce resrce){
        IPage result;
        QueryWrapper<Resrce> queryWrapper = new QueryWrapper<>();
        queryWrapper.setEntity(resrce);
        if (frontPage.getGlobalQuery() != null && !"".equals(frontPage.getGlobalQuery().trim())) {
            //TODO modify global query
            queryWrapper.lambda().and(wrapper -> wrapper
                .like(Resrce::getHandle, frontPage.getGlobalQuery())
                .or().like(Resrce::getSite, frontPage.getGlobalQuery())
                .or().like(Resrce::getResrce, frontPage.getGlobalQuery())
                .or().like(Resrce::getDescription, frontPage.getGlobalQuery())
                .or().like(Resrce::getStatusBo, frontPage.getGlobalQuery())
                .or().like(Resrce::getProcessResource, frontPage.getGlobalQuery())
                .or().like(Resrce::getOperationBo, frontPage.getGlobalQuery())
                .or().like(Resrce::getSetupState, frontPage.getGlobalQuery())
                .or().like(Resrce::getSetupDescription, frontPage.getGlobalQuery())
                .or().like(Resrce::getCncMachine, frontPage.getGlobalQuery())
                .or().like(Resrce::getPendingStatusBo, frontPage.getGlobalQuery())
                .or().like(Resrce::getPendingReasonCodeBo, frontPage.getGlobalQuery())
                .or().like(Resrce::getPendingResourceRcBo, frontPage.getGlobalQuery())
                .or().like(Resrce::getPendingComments, frontPage.getGlobalQuery())
                .or().like(Resrce::getErpPlantMaintOrder, frontPage.getGlobalQuery())
                .or().like(Resrce::getErpEquipmentNumber, frontPage.getGlobalQuery())
                .or().like(Resrce::getErpCapacityCategory, frontPage.getGlobalQuery())
    );
        }
        result = resrceService.page(frontPage.getPagePlus(), queryWrapper);
        return R.ok(result);
    }

    /**
     * 新增
     * @param resrce  传递的实体
     * @return  null 失败  实体成功
     */
    @PostMapping
    public R save(@RequestBody Resrce resrce) {
        return R.ok(resrceService.save(resrce));
    }

    /**
     * 修改
     * @param resrce  传递的实体
     * @return  null 失败  实体成功
     */
    @PutMapping
    public R updateById(@RequestBody Resrce resrce) {
        return R.ok(resrceService.updateById(resrce));
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     * @return 0 失败  1 成功
     */
    @ResponseBody
    @RequestMapping(method = RequestMethod.DELETE, value = "/{id:.+}")
    public R removeById(@PathVariable("id") String id){
        return R.ok(resrceService.removeById(id));
    }

    /**
     * 批量删除对象
     * @param ids 实体集合ID
     * @return  0 失败  1 成功
     */
    @ResponseBody
    @RequestMapping(method = RequestMethod.POST, value = "/delete-batch")
    public R removeByIds(List<String> ids){
        return R.ok(resrceService.removeByIds(ids));
    }
}