package com.foreverwin.mesnac.meapi.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.foreverwin.mesnac.meapi.model.WorkCenter;
import com.foreverwin.mesnac.meapi.service.WorkCenterService;
import com.foreverwin.modular.core.util.FrontPage;
import com.foreverwin.modular.core.util.R;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 *
 * @author Leon.L
 * @since 2021-05-26
 */
@RestController
@RequestMapping("/WORK-CENTER")
public class WorkCenterController {

    @Autowired
    public WorkCenterService workCenterService;

    /**
    * 根据id查询
    *
    * @param id 主键
    * @return
    */
    @ResponseBody
    @GetMapping("/{id:.+}")
    public R getWorkCenterById(@PathVariable String id) {
        return R.ok( workCenterService.getById(id));
    }

    /**
     * 查询所有数据
     *
     * @return
     */
    @ResponseBody
    @GetMapping("")
    public R getWorkCenterList(WorkCenter workCenter){
        List<WorkCenter> result;
        QueryWrapper<WorkCenter> queryWrapper = new QueryWrapper<>();
        queryWrapper.setEntity(workCenter);
        result = workCenterService.list(queryWrapper);
        return R.ok(result);
    }

    /**
     * 分页查询数据
     *
     * @param frontPage  分页信息
     * @return
     */
    @ResponseBody
    @GetMapping("/page")
    public R page(FrontPage<WorkCenter> frontPage, WorkCenter workCenter){
        IPage result;
        QueryWrapper<WorkCenter> queryWrapper = new QueryWrapper<>();
        queryWrapper.setEntity(workCenter);
        if (frontPage.getGlobalQuery() != null && !"".equals(frontPage.getGlobalQuery().trim())) {
            //TODO modify global query
            queryWrapper.lambda().and(wrapper -> wrapper
                .like(WorkCenter::getHandle, frontPage.getGlobalQuery())
                .or().like(WorkCenter::getSite, frontPage.getGlobalQuery())
                .or().like(WorkCenter::getWorkCenter, frontPage.getGlobalQuery())
                .or().like(WorkCenter::getRouterBo, frontPage.getGlobalQuery())
                .or().like(WorkCenter::getCanBeReleasedTo, frontPage.getGlobalQuery())
                .or().like(WorkCenter::getWcCategory, frontPage.getGlobalQuery())
                .or().like(WorkCenter::getStatusBo, frontPage.getGlobalQuery())
                .or().like(WorkCenter::getWcType, frontPage.getGlobalQuery())
                .or().like(WorkCenter::getAssignmentEnforcement, frontPage.getGlobalQuery())
                .or().like(WorkCenter::getIsErpWorkCenter, frontPage.getGlobalQuery())
                .or().like(WorkCenter::getErpWorkCenter, frontPage.getGlobalQuery())
                .or().like(WorkCenter::getErpCapacityCategory, frontPage.getGlobalQuery())
                .or().like(WorkCenter::getProductionSupplyArea, frontPage.getGlobalQuery())
                .or().like(WorkCenter::getStandardValueKeyBo, frontPage.getGlobalQuery())
    );
        }
        result = workCenterService.page(frontPage.getPagePlus(), queryWrapper);
        return R.ok(result);
    }

    /**
     * 新增
     * @param workCenter  传递的实体
     * @return  null 失败  实体成功
     */
    @PostMapping
    public R save(@RequestBody WorkCenter workCenter) {
        return R.ok(workCenterService.save(workCenter));
    }

    /**
     * 修改
     * @param workCenter  传递的实体
     * @return  null 失败  实体成功
     */
    @PutMapping
    public R updateById(@RequestBody WorkCenter workCenter) {
        return R.ok(workCenterService.updateById(workCenter));
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     * @return 0 失败  1 成功
     */
    @ResponseBody
    @RequestMapping(method = RequestMethod.DELETE, value = "/{id:.+}")
    public R removeById(@PathVariable("id") String id){
        return R.ok(workCenterService.removeById(id));
    }

    /**
     * 批量删除对象
     * @param ids 实体集合ID
     * @return  0 失败  1 成功
     */
    @ResponseBody
    @RequestMapping(method = RequestMethod.POST, value = "/delete-batch")
    public R removeByIds(List<String> ids){
        return R.ok(workCenterService.removeByIds(ids));
    }

    /**
     * 查询工作中心和工作中心描述
     * @param frontPage
     * @return
     */
    @ResponseBody
    @GetMapping("/SelectWorkCenter")
    public R getWorkCenterWcList(FrontPage frontPage){
        List<WorkCenter> result;
        String workCenter=frontPage.getGlobalQuery();
        return R.ok(workCenterService.workCenterlist(frontPage.getPagePlus(),workCenter));
    }
}